Introduction
============

Support for single-page and mobile applications is offered by the
``allauth.headless`` app.  Note that you still need to have e.g. the
``allauth.account`` app installed for this to work, yet, you can completely
disable its views using ``settings.HEADLESS_ONLY = True``.
